==> org.eclipse.osee.server.p2-0.26.0-SNAPSHOT.zip: org/eclipse/osee/ats/api/demo/DemoWorkDefinitions.java <==
/*******************************************************************************
 * Copyright (c) 2019 Boeing.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     Boeing - initial API and implementation
 *******************************************************************************/
package org.eclipse.osee.ats.api.demo;

import org.eclipse.osee.ats.api.workdef.AtsWorkDefinitionToken;

/**
 * @author Donald G. Dunne
 */
public class DemoWorkDefinitions {

   // @formatter:off
   public static AtsWorkDefinitionToken WorkDef_Team_Demo_Code = new AtsWorkDefinitionToken(48427403L, "WorkDef_Team_Demo_Code");
   public static AtsWorkDefinitionToken WorkDef_Team_Demo_SwDesign = new AtsWorkDefinitionToken(3625963L, "WorkDef_Team_Demo_SwDesign");
   public static AtsWorkDefinitionToken WorkDef_Team_Demo_Test = new AtsWorkDefinitionToken(2892554L, "WorkDef_Team_Demo_Test");
   public static AtsWorkDefinitionToken WorkDef_Team_Demo_Req = new AtsWorkDefinitionToken(46891154L, "WorkDef_Team_Demo_Req");
   public static AtsWorkDefinitionToken WorkDef_Review_Demo_Peer_SwDesign = new AtsWorkDefinitionToken(2342662L, "WorkDef_Review_Demo_Peer_SwDesign");
   public static AtsWorkDefinitionToken WorkDef_Task_Demo_SwDesign = new AtsWorkDefinitionToken(2234432L, "WorkDef_Task_Demo_SwDesign");
   // @formatter:on

}

==> org.eclipse.osee.server.p2-1.0.0-SNAPSHOT.zip: org/eclipse/osee/ats/api/demo/DemoWorkDefinitions.java <==
/*********************************************************************
 * Copyright (c) 2019 Boeing
 *
 * This program and the accompanying materials are made
 * available under the terms of the Eclipse Public License 2.0
 * which is available at https://www.eclipse.org/legal/epl-2.0/
 *
 * SPDX-License-Identifier: EPL-2.0
 *
 * Contributors:
 *     Boeing - initial API and implementation
 **********************************************************************/

package org.eclipse.osee.ats.api.demo;

import org.eclipse.osee.ats.api.workdef.AtsWorkDefinitionToken;

/**
 * @author Donald G. Dunne
 */
public class DemoWorkDefinitions {

   // @formatter:off
   public static AtsWorkDefinitionToken WorkDef_Team_Demo_Change_Request = new AtsWorkDefinitionToken(458293458L, "WorkDef_Team_Demo_Change_Request");
   public static AtsWorkDefinitionToken WorkDef_Team_Demo_Code = new AtsWorkDefinitionToken(48427403L, "WorkDef_Team_Demo_Code");
   public static AtsWorkDefinitionToken WorkDef_Team_Demo_SwDesign = new AtsWorkDefinitionToken(3625963L, "WorkDef_Team_Demo_SwDesign");
   public static AtsWorkDefinitionToken WorkDef_Team_Demo_Test = new AtsWorkDefinitionToken(2892554L, "WorkDef_Team_Demo_Test");
   public static AtsWorkDefinitionToken WorkDef_Team_Demo_Req = new AtsWorkDefinitionToken(46891154L, "WorkDef_Team_Demo_Req");

   public static AtsWorkDefinitionToken WorkDef_Review_Demo_Peer_SwDesign = new AtsWorkDefinitionToken(2342662L, "WorkDef_Review_Demo_Peer_SwDesign");

   public static AtsWorkDefinitionToken WorkDef_Task_Demo_SwDesign = new AtsWorkDefinitionToken(2234432L, "WorkDef_Task_Demo_SwDesign");
   public static AtsWorkDefinitionToken WorkDef_Task_Demo_For_CR_Estimating = new AtsWorkDefinitionToken(32922123L, "WorkDef_Task_Demo_For_CR_Estimating");
   // @formatter:on

}
